Method: Wpxf::WordPress::ShellUpload#payload_name

Defined in:
lib/wpxf/wordpress/shell_upload.rb

#payload_nameString

Returns the file name of the payload, including the file extension.

Returns:

  • (String)

    the file name of the payload, including the file extension.



41
42
43
# File 'lib/wpxf/wordpress/shell_upload.rb', line 41

def payload_name
  @payload_name
end